@@ -5,7 +5,7 @@ import sys
 from os import path, wait
 sys.path.append( path.dirname( path.dirname( path.abspath(__file__) ) ) )
 from foxrestapiclient.devices.fox_rgbw_device import DeviceData, FoxRGBWDevice
-from .const import (
+from const import (
     API_KEY,
     CHANNELS,
     HOST,
@@ -30,17 +30,23 @@ class RGBWDeviceTest(unittest.TestCase):
         )
 
     @async_test
-    async def test_async_color_hsv(self):
-        await self.device.async_set_color_hsv(100,80,70)
-        await asyncio.sleep(5)
-        hsv = await self.device.async_fetch_color_hsv()
-        self.assertEqual(hsv[0], 100)
-        self.assertEqual(hsv[1], 80)
-        self.assertEqual(hsv[2], 68)
+    async def test_set_state(self):
+        await self.device.async_update_channel_state(True)
+        await self.device.async_fetch_device_available_data()
+        self.assertTrue(self.device.is_on())
+
+    # @async_test
+    # async def test_async_color_hsv(self):
+    #     await self.device.async_set_color_hsv(100,80,70)
+    #     await asyncio.sleep(5)
+    #     hsv = await self.device.async_fetch_color_hsv()
+    #     self.assertEqual(hsv[0], 100)
+    #     self.assertEqual(hsv[1], 80)
+    #     self.assertEqual(hsv[2], 68)
 
     @async_test
     async def test_async_set_brightness(self):
-        await self.device.async_set_brightness(0)
+        await self.device.async_set_brightness(70)
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
